package com.offcn.live_android_demo;

import androidx.appcompat.app.AppCompatActivity;

import android.os.Bundle;
import android.text.TextUtils;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.TextView;
import android.widget.Toast;

import com.offcn.live.bean.ZGLEnumVideoType;
import com.offcn.live.util.OffcnLiveSDK;
import com.offcn.live.util.ZGLDownLoaderManager;

/**
 * 中公直播示例demo
 */
public class MainActivity extends AppCompatActivity implements View.OnClickListener {
    EditText mEtName;
    EditText mEtUid;
    EditText mEtPwd;
    EditText mEtDownload;
    Button mBtnEnv;
    Button mBtnLiveBc;
    Button mBtnPlaybackBc;
    Button mBtnLiveSc;
    Button mBtnPlaybackSc;
    Button mBtnDownloadStart;
    Button mBtnDownloadPause;
    Button mBtnDownloadDelete;
    Button mBtnDownloadPlayback;
    TextView mTvDownloadPercent;

    boolean mIsEnvTest = BuildConfig.DEBUG;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        mEtName = findViewById(R.id.et_name);
        mEtUid = findViewById(R.id.et_uid);
        mEtPwd = findViewById(R.id.et_pwd);
        mEtDownload = findViewById(R.id.et_download);
        mBtnEnv = findViewById(R.id.btn_env);
        mBtnLiveBc = findViewById(R.id.btn_live_bc);
        mBtnPlaybackBc = findViewById(R.id.btn_playback_bc);
        mBtnLiveSc = findViewById(R.id.btn_live_sc);
        mBtnPlaybackSc = findViewById(R.id.btn_playback_sc);
        mBtnDownloadStart = findViewById(R.id.btn_download_start);
        mBtnDownloadPause = findViewById(R.id.btn_download_pause);
        mBtnDownloadDelete = findViewById(R.id.btn_download_delete);
        mBtnDownloadPlayback = findViewById(R.id.btn_download_go);
        mTvDownloadPercent = findViewById(R.id.tv_download_percent);

        mBtnEnv.setOnClickListener(this);
        mBtnLiveBc.setOnClickListener(this);
        mBtnPlaybackBc.setOnClickListener(this);
        mBtnLiveSc.setOnClickListener(this);
        mBtnPlaybackSc.setOnClickListener(this);
        mBtnDownloadStart.setOnClickListener(this);
        mBtnDownloadPause.setOnClickListener(this);
        mBtnDownloadDelete.setOnClickListener(this);
        mBtnDownloadPlayback.setOnClickListener(this);

        mBtnEnv.setText(mIsEnvTest ? "当前为测试环境，点击更改" : "当前为正式环境，点击更改");
    }

    @Override
    public void onClick(View v) {
        int viewId = v.getId();
        switch (viewId) {
            case R.id.btn_env:
                exeEnv();
                break;
            case R.id.btn_live_bc:
                exeClick(1);
                break;
            case R.id.btn_playback_bc:
                exeClick(2);
                break;
            case R.id.btn_live_sc:
                exeClick(3);
                break;
            case R.id.btn_playback_sc:
                exeClick(4);
                break;
            case R.id.btn_download_start:
                exeDownload(1);
                break;
            case R.id.btn_download_pause:
                exeDownload(2);
                break;
            case R.id.btn_download_delete:
                exeDownload(3);
                break;
            case R.id.btn_download_go:
                exeDownload(4);
                break;
        }
    }

    /**
     * 处理环境
     */
    private void exeEnv() {
        mIsEnvTest = !mIsEnvTest;
        // 重新设置直播环境
        OffcnLiveSDK.resetEnvTest(mIsEnvTest);
        mBtnEnv.setText(mIsEnvTest ? "当前为测试环境，点击更改" : "当前为正式环境，点击更改");
    }

    /**
     * 处理直播、回放点击事件
     *
     * @param i 1大班课直播  2大班课回放  3小班课直播  4小班课回放
     */
    private void exeClick(int i) {
        String etName = mEtName.getText().toString().trim();
        String etUid = mEtUid.getText().toString().trim();
        String etPwd = mEtPwd.getText().toString().trim();

        if (TextUtils.isEmpty(etName) || TextUtils.isEmpty(etUid) || TextUtils.isEmpty(etPwd)) {
            Toast.makeText(this, "cannot be NULL", Toast.LENGTH_SHORT).show();
            return;
        }

        ZGLEnumVideoType type;
        switch (i) {
            case 1:
                type = ZGLEnumVideoType.LIVE;
                break;
            case 2:
                type = ZGLEnumVideoType.PLAYBACK;
                break;
            case 3:
                type = ZGLEnumVideoType.SMALLCLASS;
                break;
            case 4:
                type = ZGLEnumVideoType.SC_PLAYBACK;
                break;
            default:
                type = ZGLEnumVideoType.LIVE;
                break;
        }

        // 跳转至直播/回放 页面
        OffcnLiveSDK.with(this, etName, etUid, etPwd, type)
                .hook("")           // 回放及下载的第三方验证，非必须
                .extensions(null)   // 第三方透传数据，非必须
                .quitCallback(null) // 监听直播/回放退出事件，非必须
                .lastPlaybackTimeSeconds(0) // 上次回放观看时间，非必须
                .start();
    }

    /**
     * 处理下载事件
     *
     * @param i 1开始  2暂停  3删除  4下载后观看
     */
    private void exeDownload(int i) {
        String code = mEtDownload.getText().toString().trim();
        if (TextUtils.isEmpty(code)) {
            Toast.makeText(this, "cannot be NULL", Toast.LENGTH_SHORT).show();
            return;
        }

        if (i == 1) {
            // 开始下载
            ZGLDownLoaderManager.getInstance(this)
                    .extensions(null)       // 第三方透传数据，非必须
                    .downloadPath(null)     // 自定义下载路径，默认为 Android/data/com.xx.xx/files，非必须
                    .listener(new ZGLDownLoaderManager.OnZGLProgressListener() {
                        @Override
                        public void onPrepared(String code) {
                            // 准备中
                        }

                        @Override
                        public void onStart(String code) {
                            // 已开始
                        }

                        @Override
                        public void onProgress(String code, String percent) {
                            // 下载进度
                        }

                        @Override
                        public void onPaused(String code) {
                            // 已暂停
                        }

                        @Override
                        public void onSuccess(String code) {
                            // 下载成功
                        }

                        @Override
                        public void onFailed(String code, String error) {
                            // 下载失败
                        }
                    })
                    .start(code);       // 下载的房间密码，必须
        } else if (i == 2) {
            // 暂停下载
            ZGLDownLoaderManager.getInstance(this)
                    .pause(code);
        } else if (i == 3) {
            // 删除下载
            ZGLDownLoaderManager.getInstance(this)
                    .delete(code, null);
        } else if (i == 4) {
            // 观看已下载
            OffcnLiveSDK.with(this, "namestr", "uidstr", code, ZGLEnumVideoType.PLAYBACK);
        }
    }
}
